Collect prompt-grid checkpoints into one reusable results table
Source:R/prompt_grid.R
collect_prompt_grid_results.RdRead every valid prompt-grid checkpoint in one or more directories and combine it with optional prior results. This is useful after cost-gated phases because checkpoints for models that are inactive in the current configuration remain available for later analysis and reuse.
Arguments
- output_dir
Character vector of checkpoint directories created by
run_prompt_grid().- existing_results
Optional results data frame, run bundle, RDS path, or CSV path accepted by the
existing_resultsargument ofrun_prompt_grid().