List book chapter files inside a books directory
Source:R/list_book_chapters.R
list_book_chapters.RdGiven a path to a directory of book folders, return a named list where each element is a character vector of chapter file paths (ordered by number or name).