Rename chapter text files in a folder to a sequential order
Source:R/rename_chapters.R
rename_chapters.RdScans a folder for chapter files and renames them to chapter1.ext,
chapter2.ext, ...
using heuristics for ordering (intro, part 1/2, numeric chapter numbers, appendix, etc.).